.. _ref_automorphing_guide:

Optimize geometries
========================================================

In SimAI, automorphing is a non-parametric deformation of a surface geometry.

.. toctree::
   :maxdepth: 2

   non-parametric_optimization
   configure_automorphing